@@ -1,34 +1,35 @@
 //! This crate is an implementation of the Kync specification (see "Kync.asciidoc")
 
 mod ffi;
-mod plugin;
+pub mod plugin;
 
 use std::{
 	error::Error as StdError,
 	fmt::{ Display, Formatter, Result as FmtResult },
 	io::{ Error as IoError, ErrorKind as IoErrorKind }
 };
-pub use crate::{ plugin::{ Plugin, FormatUid }, ffi::{ CSlice, AsCSlice, AsCSliceMut } };
+pub use crate::{ plugin::Plugin, ffi::{ CSource, AsCSource, CSink, AsCSink } };
 
 
 /// The error kind
 #[derive(Debug, Copy, Clone, Eq, PartialEq)]
 pub enum ErrorKind {
-	/// A plugin could not initialize itself
-	InitializationError,
-	/// The provided buffer is too small and cannot be resized
-	BufferError{ required_size: usize },
 	/// An operation is not permitted (at least not without providing authentication data)
 	PermissionDenied{ requires_authentication: bool },
 	/// An authentication error occurred (e.g. bad PIN, password etc.); if the amount of retries
 	/// left is `None`, this means that there is no limit
 	AccessDenied{ retries_left: Option<u64> },
+	/// The provided buffer is too small and cannot be resized
+	BufferError{ required_size: u64 },
 	/// An IO-error occurred
 	IoError,
 	/// Invalid data
 	InvalidData,
-	/// There is no valid key available to decrypt the data
+	/// There are no capsule keys to list (because the plugin has no key store) or there is no valid
+	/// key available to decrypt the capsule
 	NoKeyAvailable,
+	/// An invalid parameter was passed
+	InvalidParameter{ index: u64 },
 	/// The operation was canceled by the user
 	OperationCancelled,
 	/// The operation timed out (e.g. took longer than 90s)
